.nbp-ui {
  font-family: Lato, sans-serif;

  .btn {
    color: @jpy-brand;
    background-color: transparent;
    border: none;
    font-size: 16px;
    opacity: 0.75;

    &:hover {
      opacity: 1;
    }

    &:active:focus, &:active:hover{
      background-color: @jpy-brand;
      color: @ui-bg;
    }

    label {
      font-size: 12px;
      text-align: center;
      display: block;
      break: both;
    }
  }
}
